@@ -39,6 +39,14 @@ def parse_options():
         help="put your har folder path for production"
     )
 
+    parser.add_option(
+        '-i','--interactive',
+        dest='is_interactive',
+        default=False,
+        action='store_true',
+        help="interactively create files"
+    )
+
     # parser.add_option(
     #    '--skip-response',
     #     dest='skip_response',
