@@ -21,7 +21,11 @@ class LurlRequest(object):
         self.response_content = ""
 
     def parse_url(self):
-        endpoint = re.findall("^http.*//[^/]*(/.*?)$", self.parsed.url)[0]
+        endpoint = re.findall("^http.*//[^/]*(/.*?)$", self.parsed.url)
+        if len(endpoint) > 0 : 
+            endpoint = endpoint[0]
+        else :
+            endpoint= "/"
         endpoint_split = endpoint.split("?",1)
         self.path = endpoint_split[0]
         if len(endpoint_split) > 1 :
