@@ -47,6 +47,7 @@ class TkpStruct(object):
         self.construct_base()
         self.base["structure"].append(self.get_production_structure())
         self.base["structure"].append(self.get_staging_structure())
+        self.base.update(self.set_content_type(self.request_presenter.parsed.data))
 
     def construct_base(self) :
         self.base = {
@@ -81,7 +82,10 @@ class TkpStruct(object):
         if self.request_presenter.method == "GET" :
             return self.get_apiParamMap_from_query(request)
         else :
-            return json.loads(request.parsed.data)
+            try :
+                return json.loads(request.parsed.data)
+            except :
+                return request.parsed.data
 
     def get_production_structure(self):
         env_name = "production"
@@ -128,6 +132,26 @@ class TkpStruct(object):
                 "responseCode":request.response.status_code
             }
         return structure
+    
+    def set_content_type(self, postdata) :
+        if self.check_form_data(postdata) :
+            return {"contentType" : "form"}
+        else :
+            return {}
+
+    def check_form_data(self, postdata):
+        is_form_data = False
+        try :
+            first_split = postdata.split("&")
+            for fd in first_split :
+                is_form_data = True
+                second_split = fd.split("=")
+                if len(second_split) == 0 :
+                    is_form_data = False
+                    break
+            return is_form_data
+        except :
+            return False
 
 
 
